<?php

namespace Drupal\safedelete\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use \Drupal\node\Entity\NodeType;

/**
 * Configure safedelete settings for this site.
 */
class SafedeleteSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'safedelete_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'safedelete.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('safedelete.settings');
    $node_types = NodeType::loadMultiple();
    if (empty($node_types)) {
      return NULL;
    }
    $options = [];
    $first_bundle = '';
    foreach ($node_types as $node_type_test => $type_test) {
      $first_bundle = $node_type_test;
      break;
    }
    foreach ($node_types as $node_type => $type) {
      $options[$node_type] = $type->get('name');
    }

    $form['bundle'] = [
      '#title' => t('Bundle'),
      '#type' => 'checkboxes',
      '#description' => t('Check the content types that you wish to add restriction on deletion'),
      '#options' => $options,
      '#default_value' => (!empty($config->get('bundle'))) ? $config->get('bundle') : [$first_bundle]
    ];

    $form['safearchive'] = [
      '#title' => t('Safe archive'),
      '#type' => 'checkbox',
      '#description' => t('This option will enable safe archive validation'),
      '#default_value' => (!empty($config->get('safearchive'))) ? $config->get('safearchive') : FALSE
    ];

    $form['delete_button'] = [
      '#title' => t('Show delete button'),
      '#type' => 'checkbox',
      '#description' => t('This option will show delete button in node delete form page, even when the node is associated with entities'),
      '#default_value' => (!empty($config->get('delete_button'))) ? $config->get('delete_button') : FALSE
    ];

    $form['limit'] = [
      '#title' => t('Number of entities list to show in node delete form'),
      '#type' => 'textfield',
      '#description' => t("Number of entities list to show in node delete form"),
      '#size' => 2,
      '#default_value' => (!empty($config->get('limit'))) ? $config->get('limit') : FALSE
    ];

    /* the definition of the orphaned page */
    $form['orphanedpagedefinition'] = [
      '#title' => t('The definition of the orphaned pages'),
      '#type' => 'checkboxes',
      '#description' => t('Check the content types that you wish to consider as the orphaned pages'),
      '#options' => $options,
      '#default_value' => (!empty($config->get('orphanedpagedefinition'))) ? $config->get('orphanedpagedefinition') : [$first_bundle]
    ];

    /* the without menu link definition of the orphaned page */
    $form['orphanedpagewithoutmenulink'] = [
      '#title' => t('Choose one type to include menu link checking in the orphaned pages logic'),
      '#type' => 'radios',
      '#description' => t('Check the content type that you wish to consider as the orphaned pages even if it is only a menu link referencing the content'),
      '#options' => $options,
      '#default_value' => (!empty($config->get('orphanedpagewithoutmenulink'))) ? $config->get('orphanedpagewithoutmenulink') : $first_bundle
    ];

    $form['exceptionofnodes'] = [
      '#title' => t('Please input the node ids into the exception list of the orphaned pages'),
      '#type' => 'textfield',
      '#size' => 160,
      '#maxlength' => 326,
      '#description' => t('Enter node ids and separate them by comma'),
      '#default_value' => $config->get('exceptionofnodes'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('safedelete.settings')
      ->set('bundle', $form_state->getValue('bundle'))
      ->set('orphanedpagedefinition', $form_state->getValue('orphanedpagedefinition'))
      ->set('orphanedpagewithoutmenulink', $form_state->getValue('orphanedpagewithoutmenulink'))
      ->set('exceptionofnodes', $form_state->getValue('exceptionofnodes'))
      ->set('delete_button', $form_state->getValue('delete_button'))
      ->set('limit', $form_state->getValue('limit'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
